package App::LoadWatcher;

use strict;
use warnings;
use 5.008008;

our $VERSION = '0.01';

1;

__END__

=head1 NAME

App::LoadWatcher - watch load average and execute a command

=head1 SYNOPSIS

 load_watcher [options] -- [command ...]

=head1 DESCRIPTION

See L<load_watcher>

=head1 AUTHOR

Masahiro Nagano E<lt>kazeburo {at} gmail.comE<gt>

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
